zeromq = require 'zeromq'
fs = require 'fs'
z85 = require 'z85'

logger = require("../shared_modules/logger")
sockets = require("../shared_modules/node_zmqsockets")

child_process = require 'child_process'

configloader = require '../shared_modules/node_configloader'

try
  serverPublicKey = fs.readFileSync "/data/curvekeys/serverPublic"
  producerPublicKey = fs.readFileSync "/data/curvekeys/producerPublic"
  producerPrivateKey = fs.readFileSync "/data/curvekeys/producerPrivate"
catch e
  child_process.execSync "omgcurvekeygen"
  serverPublicKey = fs.readFileSync("/data/curvekeys/serverPublic")
  producerPublicKey = fs.readFileSync "/data/curvekeys/producerPublic"
  producerPrivateKey = fs.readFileSync "/data/curvekeys/producerPrivate"

serverPublicKey = serverPublicKey.toString()
producerPublicKey = producerPublicKey.toString()
producerPrivateKey = producerPrivateKey.toString()

config = configloader.zmq
{ standardAddress, standardTransport, reqrepbroker, pushpullbroker, pubsubbroker } = config

repPort = ->
  transport = reqrepbroker.transport or standardTransport
  address = reqrepbroker.address or standardAddress
  port = reqrepbroker.rep
  return "#{transport}://#{address}:#{port}"

ReqSocket = ->
  return new sockets.SecureConnectedSocket("webui dealer", "dealer", repPort())
  reqSocket = zeromq.socket "dealer"
  reqSocket.curve_publickey = producerPublicKey
  reqSocket.curve_secretkey = producerPrivateKey
  reqSocket.curve_serverkey = serverPublicKey
  #set higher maximum listeners
  reqSocket.setMaxListeners(40)
  logger.info "connecting request socket to #{repPort()}"
  reqSocket.connect repPort()
  return reqSocket

subPort = ->
  transport = pubsubbroker.transport or standardTransport
  address = pubsubbroker.address or standardAddress
  port = pubsubbroker.pub
  return "#{transport}://#{address}:#{port}"

subSocket = new sockets.SecureConnectedSocket("Webui sub socket", "sub", subPort())
# subSocket = zeromq.socket('sub')
# subSocket.curve_publickey = producerPublicKey
# subSocket.curve_secretkey = producerPrivateKey
# subSocket.curve_serverkey = serverPublicKey
# logger.info("connecting sub socket to #{subPort()}")
# subSocket.connect subPort()

pushPort = ->
  transport = pushpullbroker.transport or standardTransport
  address = pushpullbroker.address or standardAddress
  port = pushpullbroker.pull
  return "#{transport}://#{address}:#{port}"

pushSocket = new sockets.SecureConnectedSocket("Webui push socket", "push", pushPort())
# pushSocket = zeromq.socket "push"
# pushSocket.curve_publickey = producerPublicKey
# pushSocket.curve_secretkey = producerPrivateKey
# pushSocket.curve_serverkey = serverPublicKey
# logger.info("connecting push socket to #{pushPort()}")
# pushSocket.connect pushPort()

exports.pushSocket = pushSocket
exports.subSocket = subSocket
exports.ReqSocket = ReqSocket
